@@ -1,17 +1,27 @@
 import importlib
 import sys
 from contextlib import ContextDecorator
+from moto.core.models import BaseMockAWS
+from typing import Any, Callable, List, Optional, TypeVar
 
 
-def lazy_load(module_name, element, boto3_name=None, backend=None):
-    def f(*args, **kwargs):
+TEST_METHOD = TypeVar("TEST_METHOD", bound=Callable[..., Any])
+
+
+def lazy_load(
+    module_name: str,
+    element: str,
+    boto3_name: Optional[str] = None,
+    backend: Optional[str] = None,
+) -> Callable[..., BaseMockAWS]:
+    def f(*args: Any, **kwargs: Any) -> Any:
         module = importlib.import_module(module_name, "moto")
         return getattr(module, element)(*args, **kwargs)
 
     setattr(f, "name", module_name.replace(".", ""))
     setattr(f, "element", element)
-    setattr(f, "boto3_name", boto3_name or f.name)
-    setattr(f, "backend", backend or f"{f.name}_backends")
+    setattr(f, "boto3_name", boto3_name or f.name)  # type: ignore[attr-defined]
+    setattr(f, "backend", backend or f"{f.name}_backends")  # type: ignore[attr-defined]
     return f
 
 
@@ -20,6 +30,7 @@ mock_acmpca = lazy_load(".acmpca", "mock_acmpca", boto3_name="acm-pca")
 mock_amp = lazy_load(".amp", "mock_amp")
 mock_apigateway = lazy_load(".apigateway", "mock_apigateway")
 mock_apigatewayv2 = lazy_load(".apigatewayv2", "mock_apigatewayv2")
+mock_appconfig = lazy_load(".appconfig", "mock_appconfig")
 mock_appsync = lazy_load(".appsync", "mock_appsync")
 mock_athena = lazy_load(".athena", "mock_athena")
 mock_applicationautoscaling = lazy_load(
@@ -175,17 +186,17 @@ mock_textract = lazy_load(".textract", "mock_textract")
 
 
 class MockAll(ContextDecorator):
-    def __init__(self):
-        self.mocks = []
+    def __init__(self) -> None:
+        self.mocks: List[Any] = []
         for mock in dir(sys.modules["moto"]):
-            if mock.startswith("mock_") and not mock == ("mock_all"):
+            if mock.startswith("mock_") and not mock == "mock_all":
                 self.mocks.append(globals()[mock]())
 
-    def __enter__(self):
+    def __enter__(self) -> None:
         for mock in self.mocks:
             mock.start()
 
-    def __exit__(self, *exc):
+    def __exit__(self, *exc: Any) -> None:
         for mock in self.mocks:
             mock.stop()
 
@@ -196,7 +207,7 @@ mock_all = MockAll
 # logging.getLogger('boto').setLevel(logging.CRITICAL)
 
 __title__ = "moto"
-__version__ = "4.1.11"
+__version__ = "4.1.12"
 
 
 try:
