@@ -306,7 +306,10 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         self.headers = request.headers
         if "host" not in self.headers:
             self.headers["host"] = urlparse(full_url).netloc
-        self.response_headers = {"server": "amazon.com"}
+        self.response_headers = {
+            "server": "amazon.com",
+            "date": datetime.datetime.now().strftime("%a, %d %b %Y %H:%M:%S GMT"),
+        }
 
         # Register visit with IAM
         from moto.iam.models import mark_account_as_visited
