@@ -215,7 +215,7 @@ class DAXBackend(BaseBackend):
         self.clusters[cluster_name].delete()
         return self.clusters[cluster_name]
 
-    @paginate(PAGINATION_MODEL)
+    @paginate(PAGINATION_MODEL)  # type: ignore[misc]
     def describe_clusters(self, cluster_names: Iterable[str]) -> List[DaxCluster]:  # type: ignore[misc]
         clusters = self.clusters
         if not cluster_names:
