@@ -2,6 +2,7 @@ import re
 from copy import copy
 from datetime import datetime, timezone
 from typing import Any, Dict, Iterator, List, Optional, Tuple
+from os import getenv
 
 from moto import settings
 from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
@@ -488,6 +489,14 @@ class CapacityProviderFailure(BaseObject):
 
 
 class Service(BaseObject, CloudFormationModel):
+    """Set the environment variable MOTO_ECS_SERVICE_RUNNING to a number of running tasks you want
+    the service to transition to, ie if set to 2:
+
+    MOTO_ECS_SERVICE_RUNNING=2
+
+    then describe_services call to return runningCount of the service AND deployment to 2
+    """
+
     def __init__(
         self,
         cluster: Cluster,
@@ -507,7 +516,6 @@ class Service(BaseObject, CloudFormationModel):
         self.cluster_arn = cluster.arn
         self.name = service_name
         self.status = "ACTIVE"
-        self.running_count = 0
         self.task_definition = task_definition.arn if task_definition else None
         self.desired_count = desired_count
         self.task_sets: List[TaskSet] = []
@@ -515,6 +523,25 @@ class Service(BaseObject, CloudFormationModel):
         self.events: List[Dict[str, Any]] = []
         self.launch_type = launch_type
         self.service_registries = service_registries or []
+        self.load_balancers = load_balancers if load_balancers is not None else []
+        self.scheduling_strategy = (
+            scheduling_strategy if scheduling_strategy is not None else "REPLICA"
+        )
+        self.platform_version = platform_version
+        self.tags = tags if tags is not None else []
+        self.region_name = cluster.region_name
+        self._account_id = backend.account_id
+        self._backend = backend
+
+        try:
+            # negative running count not allowed, set to 0 if so
+            ecs_running_count = max(int(getenv("MOTO_ECS_SERVICE_RUNNING", 0)), 0)
+        except ValueError:
+            # Unable to parse value of MOTO_ECS_SERVICE_RUNNING as an integer, set to default 0
+            ecs_running_count = 0
+
+        self.running_count = ecs_running_count
+        self.pending_count = desired_count - ecs_running_count
         if self.deployment_controller["type"] == "ECS":
             self.deployments = [
                 {
@@ -522,8 +549,8 @@ class Service(BaseObject, CloudFormationModel):
                     "desiredCount": self.desired_count,
                     "id": f"ecs-svc/{mock_random.randint(0, 32**12)}",
                     "launchType": self.launch_type,
-                    "pendingCount": self.desired_count,
-                    "runningCount": 0,
+                    "pendingCount": self.pending_count,
+                    "runningCount": ecs_running_count,
                     "status": "PRIMARY",
                     "taskDefinition": self.task_definition,
                     "updatedAt": datetime.now(timezone.utc),
@@ -531,16 +558,6 @@ class Service(BaseObject, CloudFormationModel):
             ]
         else:
             self.deployments = []
-        self.load_balancers = load_balancers if load_balancers is not None else []
-        self.scheduling_strategy = (
-            scheduling_strategy if scheduling_strategy is not None else "REPLICA"
-        )
-        self.platform_version = platform_version
-        self.tags = tags if tags is not None else []
-        self.pending_count = 0
-        self.region_name = cluster.region_name
-        self._account_id = backend.account_id
-        self._backend = backend
 
     @property
     def arn(self) -> str:
@@ -1641,6 +1658,7 @@ class EC2ContainerServiceBackend(BaseBackend):
             # It is only deleted later on
             # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.delete_service
             service.status = "INACTIVE"
+            service.pending_count = 0
             return service
 
     def register_container_instance(
