@@ -213,7 +213,7 @@ class Parameter(CloudFormationModel):
     ):
         self.account_id = account_id
         self.name = name
-        self.type = parameter_type
+        self.parameter_type = parameter_type
         self.description = description
         self.allowed_pattern = allowed_pattern
         self.keyid = keyid
@@ -224,7 +224,7 @@ class Parameter(CloudFormationModel):
         self.labels = labels or []
         self.source_result = source_result
 
-        if self.type == "SecureString":
+        if self.parameter_type == "SecureString":
             if not self.keyid:
                 self.keyid = "alias/aws/ssm"
 
@@ -236,7 +236,7 @@ class Parameter(CloudFormationModel):
         return f"kms:{self.keyid}:" + value
 
     def decrypt(self, value: str) -> Optional[str]:
-        if self.type != "SecureString":
+        if self.parameter_type != "SecureString":
             return value
 
         prefix = f"kms:{self.keyid or 'default'}:"
@@ -249,7 +249,7 @@ class Parameter(CloudFormationModel):
     ) -> Dict[str, Any]:
         r: Dict[str, Any] = {
             "Name": self.name,
-            "Type": self.type,
+            "Type": self.parameter_type,
             "Value": self.decrypt(self.value) if decrypt else self.value,
             "Version": self.version,
             "LastModifiedDate": round(self.last_modified_date, 3),
@@ -349,6 +349,10 @@ class Parameter(CloudFormationModel):
 
         ssm_backend.delete_parameter(properties.get("Name"))
 
+    @property
+    def physical_resource_id(self) -> str:
+        return self.name
+
 
 MAX_TIMEOUT_SECONDS = 3600
 
@@ -937,6 +941,48 @@ def _valid_parameter_data_type(data_type: str) -> bool:
     return data_type in ("text", "aws:ec2:image")
 
 
+class FakeMaintenanceWindowTarget:
+    def __init__(
+        self,
+        window_id: str,
+        resource_type: str,
+        targets: List[Dict[str, Any]],
+        owner_information: Optional[str],
+        name: Optional[str],
+        description: Optional[str],
+    ):
+        self.window_id = window_id
+        self.window_target_id = self.generate_id()
+        self.resource_type = resource_type
+        self.targets = targets
+        self.name = name
+        self.description = description
+        self.owner_information = owner_information
+
+    def to_json(self) -> Dict[str, Any]:
+        return {
+            "WindowId": self.window_id,
+            "WindowTargetId": self.window_target_id,
+            "ResourceType": self.resource_type,
+            "Targets": self.targets,
+            "OwnerInformation": "",
+            "Name": self.name,
+            "Description": self.description,
+        }
+
+    @staticmethod
+    def generate_id() -> str:
+        return str(random.uuid4())
+
+
+def _maintenance_window_target_filter_match(
+    filters: Optional[List[Dict[str, Any]]], target: FakeMaintenanceWindowTarget
+) -> bool:
+    if not filters and target:
+        return True
+    return False
+
+
 class FakeMaintenanceWindow:
     def __init__(
         self,
@@ -960,6 +1006,7 @@ class FakeMaintenanceWindow:
         self.schedule_offset = schedule_offset
         self.start_date = start_date
         self.end_date = end_date
+        self.targets: Dict[str, FakeMaintenanceWindowTarget] = {}
 
     def to_json(self) -> Dict[str, Any]:
         return {
@@ -982,6 +1029,58 @@ class FakeMaintenanceWindow:
         return "mw-" + "".join(str(random.choice(chars)) for _ in range(17))
 
 
+class FakePatchBaseline:
+    def __init__(
+        self,
+        name: str,
+        operating_system: str,
+        global_filters: Optional[Dict[str, Any]],
+        approval_rules: Optional[Dict[str, Any]],
+        approved_patches: Optional[List[str]],
+        approved_patches_compliance_level: Optional[str],
+        approved_patches_enable_non_security: Optional[bool],
+        rejected_patches: Optional[List[str]],
+        rejected_patches_action: Optional[str],
+        description: Optional[str],
+        sources: Optional[List[Dict[str, Any]]],
+    ):
+        self.id = FakePatchBaseline.generate_id()
+        self.operating_system = operating_system
+        self.name = name
+        self.global_filters = global_filters
+        self.approval_rules = approval_rules
+        self.approved_patches = approved_patches
+        self.approved_patches_compliance_level = approved_patches_compliance_level
+        self.approved_patches_enable_non_security = approved_patches_enable_non_security
+        self.rejected_patches = rejected_patches
+        self.rejected_patches_action = rejected_patches_action
+        self.description = description
+        self.sources = sources
+        self.default_baseline = False
+
+    def to_json(self) -> Dict[str, Any]:
+        return {
+            "BaselineId": self.id,
+            "OperatingSystem": self.operating_system,
+            "BaselineName": self.name,
+            "GlobalFilters": self.global_filters,
+            "ApprovalRules": self.approval_rules,
+            "ApprovedPatches": self.approved_patches,
+            "ApprovedPatchesComplianceLevel": self.approved_patches_compliance_level,
+            "ApprovedPatchesEnableNonSecurity": self.approved_patches_enable_non_security,
+            "RejectedPatches": self.rejected_patches,
+            "RejectedPatchesAction": self.rejected_patches_action,
+            "BaselineDescription": self.description,
+            "Sources": self.sources,
+            "DefaultBaseline": self.default_baseline,
+        }
+
+    @staticmethod
+    def generate_id() -> str:
+        chars = list(range(10)) + ["a", "b", "c", "d", "e", "f"]
+        return "pb-" + "".join(str(random.choice(chars)) for _ in range(17))
+
+
 class SimpleSystemManagerBackend(BaseBackend):
     """
     Moto supports the following default parameters out of the box:
@@ -1006,6 +1105,7 @@ class SimpleSystemManagerBackend(BaseBackend):
         self._documents: Dict[str, Documents] = {}
 
         self.windows: Dict[str, FakeMaintenanceWindow] = dict()
+        self.baselines: Dict[str, FakePatchBaseline] = dict()
 
     @staticmethod
     def default_vpc_endpoint_service(
@@ -1407,7 +1507,7 @@ class SimpleSystemManagerBackend(BaseBackend):
                                 break
                     elif _filter["Key"] == "Type":
                         for v in _filter["Values"]:
-                            if ssm_parameter.type == v:
+                            if ssm_parameter.parameter_type == v:
                                 result.append(ssm_parameter)
                                 break
                     elif _filter["Key"] == "KeyId":
@@ -1693,7 +1793,7 @@ class SimpleSystemManagerBackend(BaseBackend):
                 what = "/" + parameter.name.lstrip("/")
                 values = ["/" + value.strip("/") for value in values]
             elif key == "Type":
-                what = parameter.type
+                what = parameter.parameter_type
             elif key == "Label":
                 what = parameter.labels
                 # Label filter can only have option="Equals" (also valid implicitly)
@@ -1894,8 +1994,15 @@ class SimpleSystemManagerBackend(BaseBackend):
                     "formed as a mix of letters, numbers and the following 3 symbols .-_"
                 )
             raise ValidationException(invalid_prefix_error)
-
-        if not _valid_parameter_type(parameter_type):
+        if not parameter_type and not overwrite and not self._parameters[name]:
+            raise ValidationException(
+                "A parameter type is required when you create a parameter."
+            )
+        if (
+            not _valid_parameter_type(parameter_type)
+            and not overwrite
+            and name not in self._parameters
+        ):
             raise ValidationException(
                 f"1 validation error detected: Value '{parameter_type}' at 'type' failed to satisfy constraint: Member must satisfy enum value set: [SecureString, StringList, String]",
             )
@@ -1918,6 +2025,9 @@ class SimpleSystemManagerBackend(BaseBackend):
 
             if not overwrite:
                 return None
+            # overwriting a parameter, Type is not included in boto3 call
+            if not parameter_type and overwrite:
+                parameter_type = previous_parameter.parameter_type
 
             if len(previous_parameter_versions) >= PARAMETER_VERSION_LIMIT:
                 self._check_for_parameter_version_limit_exception(name)
@@ -2131,5 +2241,115 @@ class SimpleSystemManagerBackend(BaseBackend):
         """
         del self.windows[window_id]
 
+    def create_patch_baseline(
+        self,
+        name: str,
+        operating_system: str,
+        global_filters: Optional[Dict[str, Any]],
+        approval_rules: Optional[Dict[str, Any]],
+        approved_patches: Optional[List[str]],
+        approved_patches_compliance_level: Optional[str],
+        approved_patches_enable_non_security: Optional[bool],
+        rejected_patches: Optional[List[str]],
+        rejected_patches_action: Optional[str],
+        description: Optional[str],
+        sources: Optional[List[Dict[str, Any]]],
+        tags: Optional[List[Dict[str, str]]],
+    ) -> str:
+        """
+        Registers a patch baseline. No error handling or input validation has been implemented yet.
+        """
+        baseline = FakePatchBaseline(
+            name,
+            operating_system,
+            global_filters,
+            approval_rules,
+            approved_patches,
+            approved_patches_compliance_level,
+            approved_patches_enable_non_security,
+            rejected_patches,
+            rejected_patches_action,
+            description,
+            sources,
+        )
+        self.baselines[baseline.id] = baseline
+
+        if tags:
+            baseline_tags = {t["Key"]: t["Value"] for t in tags}
+            self.add_tags_to_resource("PatchBaseline", baseline.id, baseline_tags)
+
+        return baseline.id
+
+    def describe_patch_baselines(
+        self, filters: Optional[List[Dict[str, Any]]]
+    ) -> List[FakePatchBaseline]:
+        """
+        Returns all baselines. No pagination has been implemented yet.
+        """
+        baselines = [baseline for baseline in self.baselines.values()]
+        if filters:
+            for f in filters:
+                if f["Key"] == "NAME_PREFIX":
+                    baselines = [
+                        baseline
+                        for baseline in baselines
+                        if baseline.name in f["Values"]
+                    ]
+        return baselines
+
+    def delete_patch_baseline(self, baseline_id: str) -> None:
+        """
+        Assumes the provided BaselineId exists. No error handling has been implemented yet.
+        """
+        del self.baselines[baseline_id]
+
+    def register_target_with_maintenance_window(
+        self,
+        window_id: str,
+        resource_type: str,
+        targets: List[Dict[str, Any]],
+        owner_information: Optional[str],
+        name: Optional[str],
+        description: Optional[str],
+    ) -> str:
+        """
+        Registers a target with a maintenance window. No error handling has been implemented yet.
+        """
+        window = self.get_maintenance_window(window_id)
+
+        target = FakeMaintenanceWindowTarget(
+            window_id,
+            resource_type,
+            targets,
+            owner_information=owner_information,
+            name=name,
+            description=description,
+        )
+        window.targets[target.window_target_id] = target
+        return target.window_target_id
+
+    def deregister_target_from_maintenance_window(
+        self, window_id: str, window_target_id: str
+    ) -> None:
+        """
+        Deregisters a target from a maintenance window. No error handling has been implemented yet.
+        """
+        window = self.get_maintenance_window(window_id)
+        del window.targets[window_target_id]
+
+    def describe_maintenance_window_targets(
+        self, window_id: str, filters: Optional[List[Dict[str, Any]]]
+    ) -> List[FakeMaintenanceWindowTarget]:
+        """
+        Describes all targets for a maintenance window. No error handling has been implemented yet.
+        """
+        window = self.get_maintenance_window(window_id)
+        targets = [
+            target
+            for target in window.targets.values()
+            if _maintenance_window_target_filter_match(filters, target)
+        ]
+        return targets
+
 
 ssm_backends = BackendDict(SimpleSystemManagerBackend, "ssm")
