@@ -2,7 +2,7 @@ import json
 from typing import Any, Dict, Tuple, Union
 
 from moto.core.responses import BaseResponse
-from .exceptions import ValidationException
+from .exceptions import ValidationException, ParameterAlreadyExists
 from .models import ssm_backends, SimpleSystemManagerBackend
 
 
@@ -286,11 +286,7 @@ class SimpleSystemManagerResponse(BaseResponse):
         )
 
         if result is None:
-            error = {
-                "__type": "ParameterAlreadyExists",
-                "message": f"Parameter {name} already exists.",
-            }
-            return json.dumps(error), dict(status=400)
+            raise ParameterAlreadyExists
 
         response = {"Version": result}
         return json.dumps(response)
@@ -441,6 +437,36 @@ class SimpleSystemManagerResponse(BaseResponse):
         window = self.ssm_backend.get_maintenance_window(window_id)
         return json.dumps(window.to_json())
 
+    def register_target_with_maintenance_window(self) -> str:
+        window_target_id = self.ssm_backend.register_target_with_maintenance_window(
+            window_id=self._get_param("WindowId"),
+            resource_type=self._get_param("ResourceType"),
+            targets=self._get_param("Targets"),
+            owner_information=self._get_param("OwnerInformation"),
+            name=self._get_param("Name"),
+            description=self._get_param("Description"),
+        )
+        return json.dumps({"WindowTargetId": window_target_id})
+
+    def describe_maintenance_window_targets(self) -> str:
+        window_id = self._get_param("WindowId")
+        filters = self._get_param("Filters", [])
+        targets = [
+            target.to_json()
+            for target in self.ssm_backend.describe_maintenance_window_targets(
+                window_id, filters
+            )
+        ]
+        return json.dumps({"Targets": targets})
+
+    def deregister_target_from_maintenance_window(self) -> str:
+        window_id = self._get_param("WindowId")
+        window_target_id = self._get_param("WindowTargetId")
+        self.ssm_backend.deregister_target_from_maintenance_window(
+            window_id, window_target_id
+        )
+        return "{}"
+
     def describe_maintenance_windows(self) -> str:
         filters = self._get_param("Filters", None)
         windows = [
@@ -453,3 +479,37 @@ class SimpleSystemManagerResponse(BaseResponse):
         window_id = self._get_param("WindowId")
         self.ssm_backend.delete_maintenance_window(window_id)
         return "{}"
+
+    def create_patch_baseline(self) -> str:
+        baseline_id = self.ssm_backend.create_patch_baseline(
+            name=self._get_param("Name"),
+            operating_system=self._get_param("OperatingSystem"),
+            global_filters=self._get_param("GlobalFilters", {}),
+            approval_rules=self._get_param("ApprovalRules", {}),
+            approved_patches=self._get_param("ApprovedPatches", []),
+            approved_patches_compliance_level=self._get_param(
+                "ApprovedPatchesComplianceLevel"
+            ),
+            approved_patches_enable_non_security=self._get_param(
+                "ApprovedPatchesEnableNonSecurity"
+            ),
+            rejected_patches=self._get_param("RejectedPatches", []),
+            rejected_patches_action=self._get_param("RejectedPatchesAction"),
+            description=self._get_param("Description"),
+            sources=self._get_param("Sources", []),
+            tags=self._get_param("Tags", []),
+        )
+        return json.dumps({"BaselineId": baseline_id})
+
+    def describe_patch_baselines(self) -> str:
+        filters = self._get_param("Filters", None)
+        baselines = [
+            baseline.to_json()
+            for baseline in self.ssm_backend.describe_patch_baselines(filters)
+        ]
+        return json.dumps({"BaselineIdentities": baselines})
+
+    def delete_patch_baseline(self) -> str:
+        baseline_id = self._get_param("BaselineId")
+        self.ssm_backend.delete_patch_baseline(baseline_id)
+        return "{}"
